@@ -10,21 +10,21 @@
 
 #include <KLocalizedString>
 
-#include <fcntl.h>
 #include <arpa/inet.h>
+#include <fcntl.h>
 #include <netinet/in.h>
 #include <sys/socket.h>
 
 #include <QDebug>
 
-VncSshTunnelThread::VncSshTunnelThread(const QByteArray &host, int vncPort, int tunnelPort, int sshPort, const QByteArray &sshUserName, bool loopback) :
-    m_host(host),
-    m_vncPort(vncPort),
-    m_tunnelPort(tunnelPort),
-    m_sshPort(sshPort),
-    m_sshUserName(sshUserName),
-    m_loopback(loopback),
-    m_stop_thread(false)
+VncSshTunnelThread::VncSshTunnelThread(const QByteArray &host, int vncPort, int tunnelPort, int sshPort, const QByteArray &sshUserName, bool loopback)
+    : m_host(host)
+    , m_vncPort(vncPort)
+    , m_tunnelPort(tunnelPort)
+    , m_sshPort(sshPort)
+    , m_sshUserName(sshUserName)
+    , m_loopback(loopback)
+    , m_stop_thread(false)
 {
 }
 
@@ -34,7 +34,6 @@ VncSshTunnelThread::~VncSshTunnelThread()
     wait();
 }
 
-
 int VncSshTunnelThread::tunnelPort() const
 {
     return m_tunnelPort;
@@ -62,8 +61,7 @@ void VncSshTunnelThread::userCanceledPasswordRequest()
 
 void VncSshTunnelThread::run()
 {
-    struct CleanupHelper
-    {
+    struct CleanupHelper {
         int server_sock = -1;
         int client_sock = -1;
         ssh_session session = nullptr;
@@ -97,8 +95,7 @@ void VncSshTunnelThread::run()
     ssh_options_set(session, SSH_OPTIONS_PORT, &m_sshPort);
 
     int res = ssh_connect(session);
-    if (res != SSH_OK)
-    {
+    if (res != SSH_OK) {
         Q_EMIT errorMessage(i18n("Error connecting to %1: %2", QString::fromUtf8(m_host), QString::fromLocal8Bit(ssh_get_error(session))));
         return;
     }
@@ -138,7 +135,7 @@ void VncSshTunnelThread::run()
 
     // so that we can bind more than once in case more than one tunnel is used
     int sockopt = 1;
-    setsockopt(server_sock , SOL_SOCKET, SO_REUSEADDR, &sockopt, sizeof(sockopt));
+    setsockopt(server_sock, SOL_SOCKET, SO_REUSEADDR, &sockopt, sizeof(sockopt));
 
     {
         // bind the server socket
@@ -147,7 +144,7 @@ void VncSshTunnelThread::run()
         sin.sin_port = htons(m_tunnelPort);
         sin.sin_addr.s_addr = inet_addr("127.0.0.1");
 
-        if (bind(server_sock, (struct sockaddr*)&sin, sizeof sin) == -1) {
+        if (bind(server_sock, (struct sockaddr *)&sin, sizeof sin) == -1) {
             Q_EMIT errorMessage(i18n("Error creating tunnel socket"));
             return;
         }
@@ -182,8 +179,7 @@ void VncSshTunnelThread::run()
         struct sockaddr_in client_sin;
         socklen_t client_sin_len = sizeof client_sin;
         client_sock = accept(server_sock, (struct sockaddr *)&client_sin, &client_sin_len);
-        if (client_sock == -1)
-        {
+        if (client_sock == -1) {
             qCDebug(KRDC) << "Error on tunnel socket accept";
             return;
         }
@@ -198,8 +194,7 @@ void VncSshTunnelThread::run()
     {
         const char *forward_remote_host = m_loopback ? "127.0.0.1" : m_host.constData();
         res = ssh_channel_open_forward(forwarding_channel, forward_remote_host, m_vncPort, "127.0.0.1", 0);
-        if (res != SSH_OK || !ssh_channel_is_open(forwarding_channel))
-        {
+        if (res != SSH_OK || !ssh_channel_is_open(forwarding_channel)) {
             qCDebug(KRDC) << "SSH channel open error" << ssh_get_error(session);
             return;
         }
@@ -218,12 +213,14 @@ void VncSshTunnelThread::run()
         fd_set set;
         FD_ZERO(&set);
         FD_SET(client_sock, &set);
-        ssh_channel channels[2] = { forwarding_channel, nullptr };
-        ssh_channel channels_out[2] = { nullptr, nullptr };
+        ssh_channel channels[2] = {forwarding_channel, nullptr};
+        ssh_channel channels_out[2] = {nullptr, nullptr};
 
         res = ssh_select(channels, channels_out, client_sock + 1, &set, &timeout);
-        if (res == SSH_EINTR) continue;
-        if (res == -1) break;
+        if (res == SSH_EINTR)
+            continue;
+        if (res == -1)
+            break;
 
         bool error = false;
         if (FD_ISSET(client_sock, &set)) {
@@ -231,10 +228,7 @@ void VncSshTunnelThread::run()
             while (!error && (bytes_read = read(client_sock, client_read_buffer, sizeof client_read_buffer)) > 0) {
                 int bytes_written = 0;
                 int bytes_to_write = bytes_read;
-                for (char *ptr = client_read_buffer;
-                     bytes_to_write > 0;
-                     bytes_to_write -= bytes_written, ptr += bytes_written)
-                {
+                for (char *ptr = client_read_buffer; bytes_to_write > 0; bytes_to_write -= bytes_written, ptr += bytes_written) {
                     bytes_written = ssh_channel_write(forwarding_channel, ptr, bytes_to_write);
                     if (bytes_written <= 0) {
                         error = true;
@@ -262,17 +256,15 @@ void VncSshTunnelThread::run()
                 if (bytes_read <= 0) {
                     qCDebug(KRDC) << "error on ssh_channel_read_nonblocking";
                     error = true;
-                } else  {
+                } else {
                     channel_read_buffer_to_write = bytes_read;
                 }
             }
         }
 
         if (!error && channel_read_buffer) {
-            for (int bytes_written = 0;
-                 channel_read_buffer_to_write > 0;
-                 channel_read_buffer_to_write -= bytes_written, channel_read_buffer_ptr += bytes_written)
-            {
+            for (int bytes_written = 0; channel_read_buffer_to_write > 0;
+                 channel_read_buffer_to_write -= bytes_written, channel_read_buffer_ptr += bytes_written) {
                 bytes_written = write(client_sock, channel_read_buffer_ptr, channel_read_buffer_to_write);
                 if (bytes_written == -1 && errno == EAGAIN) {
                     // socket is full, just carry on and we will write on the next iteration
